let boardSize;
let fontSize;
let wordWrapEnabled;

function setup() {
    let canvasContainer = document.getElementById('bingo-board');
    let canvas = createCanvas(800, 800);
    canvas.parent(canvasContainer);
    boardSize = 800;  // Default board size
    fontSize = 16;    // Default font size
    wordWrapEnabled = true;  // Default word wrap setting

    redrawBoard();
}

function redrawBoard() {
    boardSize = parseInt(document.getElementById('boardSize').value);
    fontSize = parseInt(document.getElementById('fontSize').value);
    wordWrapEnabled = document.getElementById('wordWrap').checked;

    resizeCanvas(boardSize, boardSize);
    background(255);

    let shuffledTerms = shuffle(riggingTerms);
    let cellSize = boardSize / 4;

    textSize(fontSize);
    textAlign(CENTER, CENTER);

    for (let i = 0; i < 4; i++) {
        for (let j = 0; j < 4; j++) {
            let term = shuffledTerms[i * 4 + j];
            fill(255);
            stroke(0);
            rect(i * cellSize, j * cellSize, cellSize, cellSize);
            fill(0);

            if (wordWrapEnabled) {
                displayWrappedText(term, i * cellSize + cellSize / 2, j * cellSize + cellSize / 2, cellSize * 0.9);
            } else {
                text(term, i * cellSize + cellSize / 2, j * cellSize + cellSize / 2);
            }
        }
    }
}

function displayWrappedText(txt, x, y, maxWidth) {
    let words = txt.split(' ');
    let line = '';
    let lineHeight = fontSize * 1.2;
    let lines = [];

    for (let i = 0; i < words.length; i++) {
        let testLine = line + words[i] + ' ';
        let testWidth = textWidth(testLine);
        if (testWidth > maxWidth && i > 0) {
            lines.push(line);
            line = words[i] + ' ';
        } else {
            line = testLine;
        }
    }
    lines.push(line);

    for (let i = 0; i < lines.length; i++) {
        text(lines[i], x, y + (i - lines.length / 2) * lineHeight);
    }
}

function toggleControls() {
    let controlsDiv = document.getElementById('controls');
    let toggleButton = document.querySelector('.toggle-controls');
    if (controlsDiv.classList.contains('visible')) {
        controlsDiv.classList.remove('visible');
        controlsDiv.classList.add('hidden');
        toggleButton.textContent = 'Show Controls';
    } else {
        controlsDiv.classList.remove('hidden');
        controlsDiv.classList.add('visible');
        toggleButton.textContent = 'Hide Controls';
    }
}
